package com.css.simulation.resource.model.service;

import api.common.pojo.constants.DictConstants;
import api.common.pojo.param.model.VehicleParam;
import api.common.pojo.po.model.VehiclePO;
import api.common.pojo.vo.model.VehicleVO;
import api.common.util.ObjectUtil;
import api.common.util.StringUtil;
import api.common.util.TimeUtil;
import com.css.simulation.resource.common.utils.AuthUtil;
import com.css.simulation.resource.model.mapper.VehicleMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.annotation.RequestBody;

import java.sql.Timestamp;
import java.util.List;

@Service
public class VehicleService {

    @Autowired
    VehicleMapper vehicleMapper;

    public List<VehicleVO> getVehicleList(@RequestBody VehicleParam vehicleParam) {
        vehicleParam.setCreateUserId(AuthUtil.getCurrentUserId());
        vehicleParam.setShare(null);
        List<VehicleVO> list = vehicleMapper.getVehicleList(vehicleParam);
        return list;
    }

    public List<VehicleVO> getMyVehicleList(VehicleParam vehicleParam) {
        vehicleParam.setCreateUserId(AuthUtil.getCurrentUserId());
        vehicleParam.setShare(DictConstants.NO);
        List<VehicleVO> list = vehicleMapper.getVehicleList(vehicleParam);
        return list;
    }

    public VehicleVO getVehicleInfo(VehicleParam vehicleParam) {
        return vehicleMapper.getVehicleInfo(vehicleParam);
    }

    public VehiclePO saveVehicle(VehiclePO vehiclePO) {
        //常规字段赋值
        String currentUserId = AuthUtil.getCurrentUserId();
        Timestamp currentTime = TimeUtil.getNowForMysql();
        vehiclePO.setCreateUserId(currentUserId);
        vehiclePO.setCreateTime(currentTime);
        vehiclePO.setModifyUserId(currentUserId);
        vehiclePO.setModifyTime(currentTime);
        vehiclePO.setIsDeleted(DictConstants.NO);
        //名称校验
        List<VehicleVO> list = vehicleMapper.checkVehicleName(vehiclePO);
        if(ObjectUtil.isNotNull(list)){
            vehiclePO.setId(null);
            return vehiclePO;
        }
        String id = vehiclePO.getId();
        if(ObjectUtil.isNull(id)){//新增
            vehiclePO.setId(StringUtil.getRandomUUID());
            vehiclePO.setShare(DictConstants.NO);//私有
            vehiclePO.setVehicleCode(StringUtil.getRandomUUID());
            vehicleMapper.insert(vehiclePO);
        }else{//修改
            vehicleMapper.update(vehiclePO);
        }
        return vehiclePO;
    }

    public VehiclePO shareVehicle(VehiclePO vehiclePO) {
        //常规字段赋值
        String currentUserId = AuthUtil.getCurrentUserId();
        Timestamp currentTime = TimeUtil.getNowForMysql();
        vehiclePO.setCreateUserId(currentUserId);
        vehiclePO.setCreateTime(currentTime);
        vehiclePO.setModifyUserId(currentUserId);
        vehiclePO.setModifyTime(currentTime);
        vehiclePO.setIsDeleted(DictConstants.NO);

        vehiclePO.setShare(DictConstants.YES);//转公有
        vehiclePO.setId(StringUtil.getRandomUUID());
        vehiclePO.setVehicleCode(StringUtil.getRandomUUID());
        vehicleMapper.insert(vehiclePO);
        return vehiclePO;
    }

    public int delVehicleById(VehiclePO vehiclePO) {
        vehiclePO.setIsDeleted(DictConstants.YES);
        vehiclePO.setModifyUserId(AuthUtil.getCurrentUserId());
        vehiclePO.setModifyTime(TimeUtil.getNowForMysql());
        int i = vehicleMapper.delVehicleById(vehiclePO);
        return i;
    }
}
