package com.css.simulation.resource.scene.service;

import api.common.pojo.param.MinioParameter;
import api.common.pojo.param.scene.StandardsRegulationsParam;
import api.common.pojo.po.scene.StandardsRegulationsPO;
import api.common.util.FileUtil;
import api.common.util.StringUtil;
import api.common.util.TimeUtil;
import com.css.simulation.resource.common.utils.AuthUtil;
import com.css.simulation.resource.feign.FileDownService;
import com.css.simulation.resource.scene.mapper.StandardsRegulationsMapper;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import feign.Response;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.File;
import java.util.ArrayList;
import java.util.List;

@Slf4j
@Service
public class StandardsRegulationsService {

    @Resource
    private StandardsRegulationsMapper standardsRegulationsMapper;

    @Resource
    private FileDownService fileDownService;

    /**
     * 获取标准法规场景数据：
     */
    @SneakyThrows
    public void importBzFg(StandardsRegulationsParam param) {

                    MinioParameter MI=new MinioParameter();
                    MI.setObjectName(param.getJsonAddress());
                    Response download = fileDownService.download(MI);
                    String json =download.body().toString();
                    ObjectMapper objMap = new ObjectMapper();
                    JsonNode root = objMap.readTree(json);

                    StandardsRegulationsPO standardsRegulationsPO = null;
                    standardsRegulationsPO = standardsRegulationsPO.builder()
                        .regulationsId(StringUtil.getRandomUUID())
                        .sceneName(root.path("场景名称").asText())
                        .regulationType(root.path("法规类型").asText())
                        .standardType(root.path("标准类型").asText())
                        .isDeleted("0")
                        .build();
                // -------------------------------- 保存数据到 mysql --------------------------------
                    standardsRegulationsPO.setCreateTime(TimeUtil.getNowForMysql());
                    standardsRegulationsPO.setModifyTime(TimeUtil.getNowForMysql());
                    standardsRegulationsPO.setCreateUserId(AuthUtil.getCurrentUserId());
                    if(null!=param.getJsonAddress()&&!param.getJsonAddress().equals("")){
                        standardsRegulationsPO.setJsonAddress(param.getJsonAddress());
                    }
                    if(null!=param.getXmlAddress()&&!param.getXmlAddress().equals("")){
                        standardsRegulationsPO.setXmlAddress(param.getXmlAddress());
                    }
                    if(null!=param.getXodrAddress()&&!param.getXodrAddress().equals("")){
                        standardsRegulationsPO.setXodrAddress(param.getXodrAddress());
                    }
                    if(null!=param.getOsgbAddress()&&!param.getOsgbAddress().equals("")){
                        standardsRegulationsPO.setOsgbAddress(param.getOsgbAddress());
                    }
                    if(null!=param.getVideoAddress()&&!param.getVideoAddress().equals("")){
                        standardsRegulationsPO.setVideoAddress(param.getVideoAddress());
                    }
                    if(null!=param.getVideoPreview()&&!param.getVideoPreview().equals("")){
                        standardsRegulationsPO.setVideoPreview(param.getVideoPreview());
                    }
                    standardsRegulationsMapper.saveStandardsRegulations(standardsRegulationsPO);


    }
//查看列表
    public   List<StandardsRegulationsPO> querySceneNaturalList(StandardsRegulationsParam params) {
        List<StandardsRegulationsPO> list = standardsRegulationsMapper.queryStandardsRegulationsList(params);
        return list;
    }
}
